#
# spec file for package python-jupyter_ipyparallel-doc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# PDF documentation currently broken
%bcond_with pdf

%bcond_without html

%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jupyter_ipyparallel-doc
Version:        6.1.1
Release:        lp150.1.2
Summary:        Documentation for python-jupyter_ipyparallel
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/ipython/ipyparallel
Source:         https://files.pythonhosted.org/packages/source/i/ipyparallel/ipyparallel-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module jupyter_ipyparallel = %{version}}
%if %{with tests}
# Test requirements
BuildRequires:  %{python_module jupyter_ipython-iptest}
BuildRequires:  %{python_module jupyter_nbformat}
%endif
# Documentation requirements
%if %{with pdf} || %{with html}
BuildRequires:  python3-Sphinx
%endif
%if %{with pdf}
BuildRequires:  python3-Sphinx-latex
BuildRequires:  tex(unicode-math.sty)
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Provides:       %{name}-html = %{version}
Provides:       %{name}-pdf = %{version}
Obsoletes:      %{name}-html < %{version}
Obsoletes:      %{name}-pdf < %{version}
Provides:       %{python_module jupyter_ipyparallel-doc = %{version}}

%description
Documentation and help files for python-jupyter_ipyparallel.

%prep
%setup -q -n ipyparallel-%{version}
find examples -name "*.py" -exec sed -i "s|^#!/usr/bin/env python$|#!%__python3|" {} \;

%build
# Build the documentation
pushd docs
%if %{with html}
make html
rm -rf build/html/.buildinfo
%endif
%if %{with pdf}
make latexpdf
%endif
popd

%install
mkdir -p %{buildroot}%{_docdir}/python-jupyter_ipyparallel

%if %{with pdf}
cp docs/build/latex/*.pdf %{buildroot}%{_docdir}/python-jupyter_ipyparallel/
%endif

%if %{with html}
cp -r docs/build/html %{buildroot}%{_docdir}/python-jupyter_ipyparallel/
%endif

cp -r examples %{buildroot}%{_docdir}/python-jupyter_ipyparallel/
%fdupes %{buildroot}%{_docdir}/python-jupyter_ipyparallel/

%if %{with tests}
%check
export LANG=en_US.UTF-8
%python_expand iptest-%{$python_bin_suffix}
%endif

%files
%defattr(-,root,root,-)
%doc COPYING.md
%{_docdir}/python-jupyter_ipyparallel/

%changelog
* Thu Feb 15 2018 toddrme2178@gmail.com
- Update to 6.1.1
  * Fix regression in 6.1.0 preventing BatchSpawners (PBS, etc.) from launching with ipcluster.
- Update to 6.1.0
  + Compatibility fixes with related packages:
  * Fix compatibility with pyzmq 17 and tornado 5.
  * Fix compatibility with IPython ≥ 6.
  * Improve compatibility with dask.distributed ≥ 1.18.
  + New features:
  * Add :attr:`namespace` to BatchSpawners for easier extensibility.
  * Support serializing partial functions.
  * Support hostnames for machine location, not just ip addresses.
  * Add ``--location`` argument to ipcluster for setting the controller location.
    It can be a hostname or ip.
  * Engine rank matches MPI rank if engines are started with ``--mpi``.
  * Avoid duplicate pickling of the same object in maps, etc.
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Wed Sep 20 2017 toddrme2178@gmail.com
- Further improvements to notebook extension handling
* Wed Sep 20 2017 toddrme2178@gmail.com
- Fix notebook extension handling
* Wed Aug 16 2017 toddrme2178@gmail.com
- Fix shebangs
* Thu Apr 27 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 6.0.2
  * Upload fixed sdist for 6.0.1.
- Update to 6.0.1
  * Small encoding fix for Python 2.
- Update to 6.0
  * Due to a compatibility change and semver, this is a major release. However, it is not a big release.
  * The main compatibility change is that all timestamps are now timezone-aware UTC timestamps.
  * This means you may see comparison errors if you have code that uses datetime objects without timezone info (so-called naïve datetime objects).
  * Rename :meth:`Client.become_distributed` to :meth:`Client.become_dask`.
    :meth:`become_distributed` remains as an alias.
  * import joblib from a public API instead of a private one
    when using IPython Parallel as a joblib backend.
  * Compatibility fix in extensions for security changes in notebook 4.3
- Update to 5.2
  * Fix compatibility with changes in ipykernel 4.3, 4.4
  * Improve inspection of ``@remote`` decorated functions
  * :meth:`Client.wait` accepts any Future.
  * Add ``--user`` flag to :command:`ipcluster nbextension`
  * Default to one core per worker in :meth:`Client.become_distributed`.
    Override by specifying `ncores` keyword-argument.
  * Subprocess logs are no longer sent to files by default in :command:`ipcluster`.
- Update to 5.1
  * IPython Parallel 5.1 adds integration with other parallel computing tools,
    such as `dask.distributed <https://distributed.readthedocs.io>`_ and `joblib <https://pythonhosted.org/joblib>`__.
  * IPython parallel now supports the notebook-4.2 API for enabling server extensions,
    to provide the IPython clusters tab
    jupyter serverextension enable --py ipyparallel
    jupyter nbextension install --py ipyparallel
    jupyter nbextension enable --py ipyparallel
    though you can still use the more convenient single-call::
    ipcluster nbextension enable
    which does all three steps above.
  * `Slurm <https://computing.llnl.gov/tutorials/linux_clusters>`_ support is added to ipcluster.
- Update to 5.0.1
  * Fix imports in :meth:`use_cloudpickle`, :meth:`use_dill`.
  * Various typos and documentation updates to catch up with 5.0.
* Wed Feb 17 2016 toddrme2178@gmail.com
- specfile:
  * update copyright year
- update to version 5.0.0:
  * The highlight of ipyparallel 5.0 is that the Client has been
    reorganized a bit to use Futures. AsyncResults are now a Future
    subclass, so they can be `yield`ed in coroutines, etc. Views have
    also received an Executor interface. This rewrite better connects
    results to their handles, so the Client.results cache should no
    longer grow unbounded.
    + The Executor API :class:`ipyparallel.ViewExecutor`
    + Creating an Executor from a Client:
    :meth:`ipyparallel.Client.executor`
    + Each View has an :attr:`executor` attribute
  * Part of the Future refactor is that Client IO is now handled in a
    background thread, which means that :meth:`Client.spin_thread` is
    obsolete and deprecated.
  * Other changes:
    + Add :command:`ipcluster nbextension enable|disable` to toggle
    the clusters tab in Jupyter notebook
  * Less interesting development changes for users: Some
    IPython-parallel extensions to the IPython kernel have been moved
    to the ipyparallel package:
    + :mod:`ipykernel.datapub` is now :mod:`ipyparallel.datapub`
    + ipykernel Python serialization is now in
    :mod:`ipyparallel.serialize`
    + apply_request message handling is implememented in a Kernel
    subclass, rather than the base ipykernel Kernel.
- update to version 4.1.0:
  * Add :meth:`.Client.wait_interactive`
  * Improvements for specifying engines with SSH launcher.
- Split documentation into own subpackage to speed up builds.
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Fri Aug 28 2015 toddrme2178@gmail.com
- Fix conflict.
* Wed Aug 26 2015 toddrme2178@gmail.com
- Initial version
